const {
  select,
  csv,
  scaleLinear,
  max,
  min,
  extent,
  axisLeft,
  axisBottom,
} = d3;

const margin = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 50,
};
const width = innerWidth;
const height = innerHeight;
const radius = 10;

const dataUrl = [
  'https://raw.githubusercontent.com/', // Base Url
  'curran/data', // github repo
  '/gh-pages/indiaGovOpenData/', // commit
  'All_India_Index-February2016.csv', // file name
].join('');

const processRow = (d) => {
  if (d.Sector == 'Rural') {
    return {
      year: +d.Year,
      education: +d.Education,
    };
  }
};

const xValue = (d) => d.year;
const yValue = (d) => d.education;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = (async () => {
  const raw = await csv(dataUrl, processRow);
  const res = raw.reduce(
    (acc, { year, education }) => {
      if (acc[year])
        acc[year].education.push(education);
      else acc[year] = { education: [education] };
      return acc;
    },
    {}
  );
  const data = Object.entries(res).map(
    ([year, { education }]) => ({
      year: +year,
      education:
        education.reduce((acc, v) => acc + v, 0) /
        education.length,
    })
  );

  console.log(data);

  const x = scaleLinear()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);

  const y = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([height - margin.top, margin.bottom]);

  const marks = data.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
  }));

  svg
    .selectAll('circle')
    .data(marks)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 10);

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${0}, ${height - margin.bottom})`
    )
    .call(axisBottom(x));
  
  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, ${0})`
    )
    .call(axisLeft(y));
})();







